@@ -251,8 +251,8 @@ def CreateImageLoaders(s3, bucket, dataset_dfn, class_dict,
     np.random.shuffle(indices)
 
     pin_memory = False
-    if cuda:
-        pin_memory = True
+    # if cuda:
+    #     pin_memory = True
 
     startIndex = 0
     allocated = 0.0
